<?php
/**
 * Plugin Name: Simple Profile Picture Uploader
 * Plugin URI: https://arajans.com
 * Description: Allows users to upload their own profile pictures to their WordPress profiles. This plugin uses WordPress's built-in avatar system and provides an alternative to Gravatar.
 * Version: 1.1
 * Author: Şiyar Kendirci
 * Author URI: https://arajans.com
 * License: GPLv2 or later
 * Text Domain: simple-profile-picture
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Simple_Profile_Picture {

    public function __construct() {
        add_action( 'show_user_profile', array( $this, 'add_profile_field' ) ); // Own profile page
        add_action( 'edit_user_profile', array( $this, 'add_profile_field' ) ); // Edit other user's profile page
        add_action( 'personal_options_update', array( $this, 'save_profile_field' ) );
        add_action( 'edit_user_profile_update', array( $this, 'save_profile_field' ) );
        add_filter( 'get_avatar_data', array( $this, 'show_local_avatar' ), 10, 2 );
        add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );
    }

    /**
     * Enqueues necessary admin scripts (for Media Library).
     */
    public function enqueue_admin_scripts( $hook_suffix ) {
        // Enqueue only on profile editing pages
        if ( 'profile.php' !== $hook_suffix && 'user-edit.php' !== $hook_suffix ) {
            return;
        }
        wp_enqueue_media(); // Enable WordPress media uploader
        wp_enqueue_script(
            'spp-admin-script',
            plugin_dir_url( __FILE__ ) . 'js/admin-script.js',
            array( 'jquery' ),
            '1.1',
            true
        );
        wp_localize_script('spp-admin-script', 'spp_params', array(
            'title' => __('Select or Upload Profile Picture', 'simple-profile-picture'),
            'button' => __('Use This Picture', 'simple-profile-picture'),
        ));
    }


    /**
     * Adds profile picture upload field to user profile.
     */
    public function add_profile_field( $user ) {
        $user_id = $user->ID;
        $avatar_id = get_user_meta( $user_id, 'spp_profile_picture_id', true );
        $avatar_url = $avatar_id ? wp_get_attachment_image_url( $avatar_id, 'thumbnail' ) : '';
        ?>
        <h3><?php _e( 'Profile Picture', 'simple-profile-picture' ); ?></h3>
        <table class="form-table">
            <tr>
                <th><label for="spp_profile_picture"><?php _e( 'Custom Profile Picture', 'simple-profile-picture' ); ?></label></th>
                <td>
                    <input type="hidden" name="spp_profile_picture_id" id="spp_profile_picture_id" value="<?php echo esc_attr( $avatar_id ); ?>" class="regular-text" />
                    <img id="spp-avatar-preview" src="<?php echo esc_url( $avatar_url ); ?>" style="width: 96px; height: 96px; display: <?php echo $avatar_url ? 'block' : 'none'; ?>; border: 1px solid #ddd; margin-bottom: 10px;" />
                    <button type="button" class="button" id="spp_upload_image_button"><?php _e( 'Select/Upload Photo', 'simple-profile-picture' ); ?></button>
                    <button type="button" class="button" id="spp_remove_image_button" style="display: <?php echo $avatar_url ? 'inline-block' : 'none'; ?>;"><?php _e( 'Remove Photo', 'simple-profile-picture' ); ?></button>
                    <p class="description">
                        <?php _e( 'Upload a custom profile picture to be used instead of Gravatar. A square image is recommended.', 'simple-profile-picture' ); ?>
                    </p>
                </td>
            </tr>
        </table>
        <?php
    }

    /**
     * Saves the uploaded photo ID as user meta.
     */
    public function save_profile_field( $user_id ) {
        if ( ! current_user_can( 'edit_user', $user_id ) ) {
            return false;
        }
        if ( isset( $_POST['spp_profile_picture_id'] ) ) {
            $avatar_id = sanitize_text_field( $_POST['spp_profile_picture_id'] );
            if (empty($avatar_id)) { // If ID is empty, meaning the photo was removed
                delete_user_meta( $user_id, 'spp_profile_picture_id' );
            } else {
                update_user_meta( $user_id, 'spp_profile_picture_id', absint( $avatar_id ) );
            }
        }
    }

    /**
     * Displays the local avatar when get_avatar or get_avatar_url is called.
     */
    public function show_local_avatar( $args, $id_or_email ) {
        $user_id = false;

        if ( is_numeric( $id_or_email ) ) {
            $user_id = (int) $id_or_email;
        } elseif ( is_object( $id_or_email ) ) {
            if ( ! empty( $id_or_email->user_id ) ) {
                $user_id = (int) $id_or_email->user_id;
            }
        } else {
            $user = get_user_by( 'email', $id_or_email );
            if ( $user ) {
                $user_id = $user->ID;
            }
        }

        if ( ! $user_id ) {
            return $args; // Return default if user not found
        }

        $local_avatar_id = get_user_meta( $user_id, 'spp_profile_picture_id', true );

        if ( $local_avatar_id ) {
            $avatar_url = wp_get_attachment_image_url( $local_avatar_id, 'thumbnail' ); // 'thumbnail' or $args['size']
            if ($avatar_url) {
                 // If size is specified and not in URL, resizing can be attempted (more advanced scenario)
                // For now, we use thumbnail size directly or the original.
                // We are modifying the 'url' argument of get_avatar_data.
                $args['url'] = $avatar_url;
                $args['found_avatar'] = true; // Inform WordPress that we found an avatar
            }
        }
        return $args;
    }
}

// Initialize the plugin
new Simple_Profile_Picture();

/**
 * Function to run when the plugin is activated.
 */
function spp_activate() {
    // Activation processes if necessary (e.g., adding default settings)
}
register_activation_hook( __FILE__, 'spp_activate' );

/**
 * Function to run when the plugin is deactivated.
 */
function spp_deactivate() {
    // Deactivation processes if necessary
}
register_deactivation_hook( __FILE__, 'spp_deactivate' );

/**
 * Function to run when the plugin is uninstalled.
 */
function spp_uninstall() {
    // Delete plugin-related meta data from the database
    // Caution: This action is irreversible. User photos are not deleted, only the link is removed.
    // $all_users = get_users( array( 'fields' => 'ID' ) );
    // foreach ( $all_users as $user_id ) {
    //     delete_user_meta( $user_id, 'spp_profile_picture_id' );
    // }
}
// register_uninstall_hook(__FILE__, 'spp_uninstall'); // Optional: Uninstall hook

/**
 * Loads the language files for the plugin.
 */
function spp_load_textdomain() {
    load_plugin_textdomain( 'simple-profile-picture', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'spp_load_textdomain' );

?>